@@ -13,6 +13,7 @@ import sys
 
 parser = ArgumentParser(description='print vyper ASTs')
 parser.add_argument('--force-terminal', action="store_true", help="pass `force_terminal=True` to rich's console constructor. Use for overriding terminal detection and including colorized output even for file outputs.", dest='term')
+parser.add_argument('--fold', action="store_true", help="export folded AST")
 
 def node_printer(node):
     match node.ast_type:
@@ -46,6 +47,7 @@ def ast_to_rich_tree(node, rich_tree=None):
         rich_tree = Tree(node_printer(node))
     else:
         rich_tree = rich_tree.add(node_printer(node))
+
     for child_node in node.get_children():
         ast_to_rich_tree(child_node, rich_tree)
     return rich_tree
@@ -62,6 +64,8 @@ def main():
         src += line
 
     ast = phases.generate_ast(src, 0, "")
+    if args.fold:
+        (ast, _) = phases.generate_folded_ast(ast, None)
 
     tree = ast_to_rich_tree(ast)
     console.print(tree)
